/* app_settings.c generated by valac 0.16.0, the Vala compiler
 * generated from app_settings.vala, do not modify */

/*
 * This file is part of LaTeXila.
 *
 * Copyright © 2010-2011 Sébastien Wilmet
 *
 * LaTeXila is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * LaTeXila is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with LaTeXila.  If not, see <http://www.gnu.org/licenses/>.
 */

#include <glib.h>
#include <glib-object.h>
#include <gio/gio.h>
#include <stdlib.h>
#include <string.h>
#include "config.h"
#include <gtksourceview/gtksourcestyleschememanager.h>
#include <gtksourceview/gtksourceview.h>
#include <gtk/gtk.h>


#define TYPE_APP_SETTINGS (app_settings_get_type ())
#define APP_SETTINGS(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_APP_SETTINGS, AppSettings))
#define APP_SETTINGS_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_APP_SETTINGS, AppSettingsClass))
#define IS_APP_SETTINGS(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_APP_SETTINGS))
#define IS_APP_SETTINGS_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_APP_SETTINGS))
#define APP_SETTINGS_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_APP_SETTINGS, AppSettingsClass))

typedef struct _AppSettings AppSettings;
typedef struct _AppSettingsClass AppSettingsClass;
typedef struct _AppSettingsPrivate AppSettingsPrivate;
#define _g_object_unref0(var) ((var == NULL) ? NULL : (var = (g_object_unref (var), NULL)))
#define _g_free0(var) (var = (g_free (var), NULL))

#define TYPE_LATEXILA (latexila_get_type ())
#define LATEXILA(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_LATEXILA, Latexila))
#define LATEXILA_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_LATEXILA, LatexilaClass))
#define IS_LATEXILA(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_LATEXILA))
#define IS_LATEXILA_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_LATEXILA))
#define LATEXILA_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_LATEXILA, LatexilaClass))

typedef struct _Latexila Latexila;
typedef struct _LatexilaClass LatexilaClass;

#define TYPE_DOCUMENT (document_get_type ())
#define DOCUMENT(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_DOCUMENT, Document))
#define DOCUMENT_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_DOCUMENT, DocumentClass))
#define IS_DOCUMENT(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_DOCUMENT))
#define IS_DOCUMENT_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_DOCUMENT))
#define DOCUMENT_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_DOCUMENT, DocumentClass))

typedef struct _Document Document;
typedef struct _DocumentClass DocumentClass;
#define __g_list_free__g_object_unref0_0(var) ((var == NULL) ? NULL : (var = (_g_list_free__g_object_unref0_ (var), NULL)))

#define TYPE_DOCUMENT_VIEW (document_view_get_type ())
#define DOCUMENT_VIEW(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_DOCUMENT_VIEW, DocumentView))
#define DOCUMENT_VIEW_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_DOCUMENT_VIEW, DocumentViewClass))
#define IS_DOCUMENT_VIEW(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_DOCUMENT_VIEW))
#define IS_DOCUMENT_VIEW_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_DOCUMENT_VIEW))
#define DOCUMENT_VIEW_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_DOCUMENT_VIEW, DocumentViewClass))

typedef struct _DocumentView DocumentView;
typedef struct _DocumentViewClass DocumentViewClass;
typedef struct _DocumentPrivate DocumentPrivate;

#define TYPE_DOCUMENT_TAB (document_tab_get_type ())
#define DOCUMENT_TAB(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_DOCUMENT_TAB, DocumentTab))
#define DOCUMENT_TAB_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_DOCUMENT_TAB, DocumentTabClass))
#define IS_DOCUMENT_TAB(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_DOCUMENT_TAB))
#define IS_DOCUMENT_TAB_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_DOCUMENT_TAB))
#define DOCUMENT_TAB_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_DOCUMENT_TAB, DocumentTabClass))

typedef struct _DocumentTab DocumentTab;
typedef struct _DocumentTabClass DocumentTabClass;

struct _AppSettings {
	GSettings parent_instance;
	AppSettingsPrivate * priv;
};

struct _AppSettingsClass {
	GSettingsClass parent_class;
};

struct _AppSettingsPrivate {
	GSettings* editor;
	GSettings* desktop_interface;
	guint timeout_id;
	gchar* _system_font;
};

struct _Document {
	GtkSourceBuffer parent_instance;
	DocumentPrivate * priv;
	DocumentTab* tab;
	guint _unsaved_doc_num;
};

struct _DocumentClass {
	GtkSourceBufferClass parent_class;
};


static gpointer app_settings_parent_class = NULL;
static AppSettings* app_settings_instance;
static AppSettings* app_settings_instance = NULL;

GType app_settings_get_type (void) G_GNUC_CONST;
#define APP_SETTINGS_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), TYPE_APP_SETTINGS, AppSettingsPrivate))
enum  {
	APP_SETTINGS_DUMMY_PROPERTY,
	APP_SETTINGS_SYSTEM_FONT
};
static AppSettings* app_settings_new (void);
static AppSettings* app_settings_construct (GType object_type);
static void app_settings_initialize (AppSettings* self);
AppSettings* app_settings_get_default (void);
static void app_settings_set_system_font (AppSettings* self, const gchar* value);
static void ___lambda4_ (AppSettings* self, GSettings* setting, const gchar* key);
static void app_settings_set_font (AppSettings* self, const gchar* font);
const gchar* app_settings_get_system_font (AppSettings* self);
static void ____lambda4__g_settings_changed (GSettings* _sender, const gchar* key, gpointer self);
static void __lambda5_ (AppSettings* self, GSettings* setting, const gchar* key);
static void ___lambda5__g_settings_changed (GSettings* _sender, const gchar* key, gpointer self);
static void __lambda6_ (AppSettings* self, GSettings* setting, const gchar* key);
static void ___lambda6__g_settings_changed (GSettings* _sender, const gchar* key, gpointer self);
static void __lambda7_ (AppSettings* self, GSettings* setting, const gchar* key);
GType latexila_get_type (void) G_GNUC_CONST;
Latexila* latexila_get_default (void);
GType document_get_type (void) G_GNUC_CONST;
GList* latexila_get_documents (Latexila* self);
static void _g_object_unref0_ (gpointer var);
static void _g_list_free__g_object_unref0_ (GList* self);
static void ___lambda7__g_settings_changed (GSettings* _sender, const gchar* key, gpointer self);
static void __lambda8_ (AppSettings* self, GSettings* setting, const gchar* key);
GType document_view_get_type (void) G_GNUC_CONST;
GList* latexila_get_views (Latexila* self);
static void ___lambda8__g_settings_changed (GSettings* _sender, const gchar* key, gpointer self);
static void __lambda9_ (AppSettings* self, GSettings* setting, const gchar* key);
static void ___lambda9__g_settings_changed (GSettings* _sender, const gchar* key, gpointer self);
static void __lambda10_ (AppSettings* self, GSettings* setting, const gchar* key);
static void ___lambda10__g_settings_changed (GSettings* _sender, const gchar* key, gpointer self);
static void __lambda11_ (AppSettings* self, GSettings* setting, const gchar* key);
static void ___lambda11__g_settings_changed (GSettings* _sender, const gchar* key, gpointer self);
static void __lambda12_ (AppSettings* self, GSettings* setting, const gchar* key);
static void ___lambda12__g_settings_changed (GSettings* _sender, const gchar* key, gpointer self);
static void __lambda13_ (AppSettings* self, GSettings* setting, const gchar* key);
GType document_tab_get_type (void) G_GNUC_CONST;
void document_tab_set_auto_save (DocumentTab* self, gboolean value);
static void ___lambda13__g_settings_changed (GSettings* _sender, const gchar* key, gpointer self);
static void __lambda16_ (AppSettings* self, GSettings* setting, const gchar* key);
void document_tab_set_auto_save_interval (DocumentTab* self, guint value);
static void ___lambda16__g_settings_changed (GSettings* _sender, const gchar* key, gpointer self);
static void __lambda17_ (AppSettings* self, GSettings* setting, const gchar* key);
static gboolean __lambda18_ (AppSettings* self);
void symbols_reload_most_used_symbols (void);
static gboolean ___lambda18__gsource_func (gpointer self);
static void ___lambda17__g_settings_changed (GSettings* _sender, const gchar* key, gpointer self);
void document_view_set_font_from_string (DocumentView* self, const gchar* font);
static void app_settings_finalize (GObject* obj);
static void _vala_app_settings_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec);
static void _vala_app_settings_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec);


static AppSettings* app_settings_construct (GType object_type) {
	AppSettings * self = NULL;
	self = (AppSettings*) g_object_new (object_type, "schema", "org.gnome.latexila", NULL);
	app_settings_initialize (self);
	return self;
}


static AppSettings* app_settings_new (void) {
	return app_settings_construct (TYPE_APP_SETTINGS);
}


static gpointer _g_object_ref0 (gpointer self) {
	return self ? g_object_ref (self) : NULL;
}


AppSettings* app_settings_get_default (void) {
	AppSettings* result = NULL;
	AppSettings* _tmp0_;
	AppSettings* _tmp2_;
	AppSettings* _tmp3_;
	_tmp0_ = app_settings_instance;
	if (_tmp0_ == NULL) {
		AppSettings* _tmp1_;
		_tmp1_ = app_settings_new ();
		_g_object_unref0 (app_settings_instance);
		app_settings_instance = _tmp1_;
	}
	_tmp2_ = app_settings_instance;
	_tmp3_ = _g_object_ref0 (_tmp2_);
	result = _tmp3_;
	return result;
}


static void ___lambda4_ (AppSettings* self, GSettings* setting, const gchar* key) {
	GSettings* _tmp0_;
	const gchar* _tmp1_;
	gchar* _tmp2_ = NULL;
	gchar* _tmp3_;
	GSettings* _tmp4_;
	gboolean _tmp5_ = FALSE;
	g_return_if_fail (setting != NULL);
	g_return_if_fail (key != NULL);
	_tmp0_ = setting;
	_tmp1_ = key;
	_tmp2_ = g_settings_get_string (_tmp0_, _tmp1_);
	_tmp3_ = _tmp2_;
	app_settings_set_system_font (self, _tmp3_);
	_g_free0 (_tmp3_);
	_tmp4_ = self->priv->editor;
	_tmp5_ = g_settings_get_boolean (_tmp4_, "use-default-font");
	if (_tmp5_) {
		const gchar* _tmp6_;
		_tmp6_ = self->priv->_system_font;
		app_settings_set_font (self, _tmp6_);
	}
}


static void ____lambda4__g_settings_changed (GSettings* _sender, const gchar* key, gpointer self) {
	___lambda4_ (self, _sender, key);
}


static void __lambda5_ (AppSettings* self, GSettings* setting, const gchar* key) {
	GSettings* _tmp0_;
	const gchar* _tmp1_;
	gboolean _tmp2_ = FALSE;
	gboolean val;
	gchar* _tmp3_ = NULL;
	gboolean _tmp4_;
	const gchar* _tmp9_;
	gchar* _tmp10_;
	gchar* font;
	g_return_if_fail (setting != NULL);
	g_return_if_fail (key != NULL);
	_tmp0_ = setting;
	_tmp1_ = key;
	_tmp2_ = g_settings_get_boolean (_tmp0_, _tmp1_);
	val = _tmp2_;
	_tmp4_ = val;
	if (_tmp4_) {
		const gchar* _tmp5_;
		gchar* _tmp6_;
		_tmp5_ = self->priv->_system_font;
		_tmp6_ = g_strdup (_tmp5_);
		_g_free0 (_tmp3_);
		_tmp3_ = _tmp6_;
	} else {
		GSettings* _tmp7_;
		gchar* _tmp8_ = NULL;
		_tmp7_ = self->priv->editor;
		_tmp8_ = g_settings_get_string (_tmp7_, "editor-font");
		_g_free0 (_tmp3_);
		_tmp3_ = _tmp8_;
	}
	_tmp9_ = _tmp3_;
	_tmp10_ = g_strdup (_tmp9_);
	font = _tmp10_;
	app_settings_set_font (self, font);
	_g_free0 (font);
	_g_free0 (_tmp3_);
}


static void ___lambda5__g_settings_changed (GSettings* _sender, const gchar* key, gpointer self) {
	__lambda5_ (self, _sender, key);
}


static void __lambda6_ (AppSettings* self, GSettings* setting, const gchar* key) {
	GSettings* _tmp0_;
	gboolean _tmp1_ = FALSE;
	GSettings* _tmp2_;
	const gchar* _tmp3_;
	gchar* _tmp4_ = NULL;
	gchar* _tmp5_;
	g_return_if_fail (setting != NULL);
	g_return_if_fail (key != NULL);
	_tmp0_ = self->priv->editor;
	_tmp1_ = g_settings_get_boolean (_tmp0_, "use-default-font");
	if (_tmp1_) {
		return;
	}
	_tmp2_ = setting;
	_tmp3_ = key;
	_tmp4_ = g_settings_get_string (_tmp2_, _tmp3_);
	_tmp5_ = _tmp4_;
	app_settings_set_font (self, _tmp5_);
	_g_free0 (_tmp5_);
}


static void ___lambda6__g_settings_changed (GSettings* _sender, const gchar* key, gpointer self) {
	__lambda6_ (self, _sender, key);
}


static void _g_object_unref0_ (gpointer var) {
	(var == NULL) ? NULL : (var = (g_object_unref (var), NULL));
}


static void _g_list_free__g_object_unref0_ (GList* self) {
	g_list_foreach (self, (GFunc) _g_object_unref0_, NULL);
	g_list_free (self);
}


static void __lambda7_ (AppSettings* self, GSettings* setting, const gchar* key) {
	GSettings* _tmp0_;
	const gchar* _tmp1_;
	gchar* _tmp2_ = NULL;
	gchar* scheme_id;
	GtkSourceStyleSchemeManager* _tmp3_ = NULL;
	GtkSourceStyleSchemeManager* _tmp4_;
	GtkSourceStyleSchemeManager* manager;
	GtkSourceStyleSchemeManager* _tmp5_;
	const gchar* _tmp6_;
	GtkSourceStyleScheme* _tmp7_ = NULL;
	GtkSourceStyleScheme* _tmp8_;
	GtkSourceStyleScheme* scheme;
	Latexila* _tmp9_ = NULL;
	Latexila* _tmp10_;
	GList* _tmp11_ = NULL;
	GList* _tmp12_;
	g_return_if_fail (setting != NULL);
	g_return_if_fail (key != NULL);
	_tmp0_ = setting;
	_tmp1_ = key;
	_tmp2_ = g_settings_get_string (_tmp0_, _tmp1_);
	scheme_id = _tmp2_;
	_tmp3_ = gtk_source_style_scheme_manager_get_default ();
	_tmp4_ = _g_object_ref0 (_tmp3_);
	manager = _tmp4_;
	_tmp5_ = manager;
	_tmp6_ = scheme_id;
	_tmp7_ = gtk_source_style_scheme_manager_get_scheme (_tmp5_, _tmp6_);
	_tmp8_ = _g_object_ref0 (_tmp7_);
	scheme = _tmp8_;
	_tmp9_ = latexila_get_default ();
	_tmp10_ = _tmp9_;
	_tmp11_ = latexila_get_documents (_tmp10_);
	_tmp12_ = _tmp11_;
	_g_object_unref0 (_tmp10_);
	{
		GList* doc_collection = NULL;
		GList* doc_it = NULL;
		doc_collection = _tmp12_;
		for (doc_it = doc_collection; doc_it != NULL; doc_it = doc_it->next) {
			Document* _tmp13_;
			Document* doc = NULL;
			_tmp13_ = _g_object_ref0 ((Document*) doc_it->data);
			doc = _tmp13_;
			{
				Document* _tmp14_;
				GtkSourceStyleScheme* _tmp15_;
				_tmp14_ = doc;
				_tmp15_ = scheme;
				gtk_source_buffer_set_style_scheme ((GtkSourceBuffer*) _tmp14_, _tmp15_);
				_g_object_unref0 (doc);
			}
		}
		__g_list_free__g_object_unref0_0 (doc_collection);
	}
	_g_object_unref0 (scheme);
	_g_object_unref0 (manager);
	_g_free0 (scheme_id);
}


static void ___lambda7__g_settings_changed (GSettings* _sender, const gchar* key, gpointer self) {
	__lambda7_ (self, _sender, key);
}


static void __lambda8_ (AppSettings* self, GSettings* setting, const gchar* key) {
	guint val = 0U;
	GSettings* _tmp0_;
	const gchar* _tmp1_;
	Latexila* _tmp2_ = NULL;
	Latexila* _tmp3_;
	GList* _tmp4_ = NULL;
	GList* _tmp5_;
	g_return_if_fail (setting != NULL);
	g_return_if_fail (key != NULL);
	_tmp0_ = setting;
	_tmp1_ = key;
	g_settings_get (_tmp0_, _tmp1_, "u", &val);
	_tmp2_ = latexila_get_default ();
	_tmp3_ = _tmp2_;
	_tmp4_ = latexila_get_views (_tmp3_);
	_tmp5_ = _tmp4_;
	_g_object_unref0 (_tmp3_);
	{
		GList* view_collection = NULL;
		GList* view_it = NULL;
		view_collection = _tmp5_;
		for (view_it = view_collection; view_it != NULL; view_it = view_it->next) {
			DocumentView* _tmp6_;
			DocumentView* view = NULL;
			_tmp6_ = _g_object_ref0 ((DocumentView*) view_it->data);
			view = _tmp6_;
			{
				DocumentView* _tmp7_;
				guint _tmp8_;
				_tmp7_ = view;
				_tmp8_ = val;
				gtk_source_view_set_tab_width ((GtkSourceView*) _tmp7_, _tmp8_);
				_g_object_unref0 (view);
			}
		}
		__g_list_free__g_object_unref0_0 (view_collection);
	}
}


static void ___lambda8__g_settings_changed (GSettings* _sender, const gchar* key, gpointer self) {
	__lambda8_ (self, _sender, key);
}


static void __lambda9_ (AppSettings* self, GSettings* setting, const gchar* key) {
	GSettings* _tmp0_;
	const gchar* _tmp1_;
	gboolean _tmp2_ = FALSE;
	gboolean val;
	Latexila* _tmp3_ = NULL;
	Latexila* _tmp4_;
	GList* _tmp5_ = NULL;
	GList* _tmp6_;
	g_return_if_fail (setting != NULL);
	g_return_if_fail (key != NULL);
	_tmp0_ = setting;
	_tmp1_ = key;
	_tmp2_ = g_settings_get_boolean (_tmp0_, _tmp1_);
	val = _tmp2_;
	_tmp3_ = latexila_get_default ();
	_tmp4_ = _tmp3_;
	_tmp5_ = latexila_get_views (_tmp4_);
	_tmp6_ = _tmp5_;
	_g_object_unref0 (_tmp4_);
	{
		GList* view_collection = NULL;
		GList* view_it = NULL;
		view_collection = _tmp6_;
		for (view_it = view_collection; view_it != NULL; view_it = view_it->next) {
			DocumentView* _tmp7_;
			DocumentView* view = NULL;
			_tmp7_ = _g_object_ref0 ((DocumentView*) view_it->data);
			view = _tmp7_;
			{
				DocumentView* _tmp8_;
				gboolean _tmp9_;
				_tmp8_ = view;
				_tmp9_ = val;
				gtk_source_view_set_insert_spaces_instead_of_tabs ((GtkSourceView*) _tmp8_, _tmp9_);
				_g_object_unref0 (view);
			}
		}
		__g_list_free__g_object_unref0_0 (view_collection);
	}
}


static void ___lambda9__g_settings_changed (GSettings* _sender, const gchar* key, gpointer self) {
	__lambda9_ (self, _sender, key);
}


static void __lambda10_ (AppSettings* self, GSettings* setting, const gchar* key) {
	GSettings* _tmp0_;
	const gchar* _tmp1_;
	gboolean _tmp2_ = FALSE;
	gboolean val;
	Latexila* _tmp3_ = NULL;
	Latexila* _tmp4_;
	GList* _tmp5_ = NULL;
	GList* _tmp6_;
	g_return_if_fail (setting != NULL);
	g_return_if_fail (key != NULL);
	_tmp0_ = setting;
	_tmp1_ = key;
	_tmp2_ = g_settings_get_boolean (_tmp0_, _tmp1_);
	val = _tmp2_;
	_tmp3_ = latexila_get_default ();
	_tmp4_ = _tmp3_;
	_tmp5_ = latexila_get_views (_tmp4_);
	_tmp6_ = _tmp5_;
	_g_object_unref0 (_tmp4_);
	{
		GList* view_collection = NULL;
		GList* view_it = NULL;
		view_collection = _tmp6_;
		for (view_it = view_collection; view_it != NULL; view_it = view_it->next) {
			DocumentView* _tmp7_;
			DocumentView* view = NULL;
			_tmp7_ = _g_object_ref0 ((DocumentView*) view_it->data);
			view = _tmp7_;
			{
				DocumentView* _tmp8_;
				gboolean _tmp9_;
				_tmp8_ = view;
				_tmp9_ = val;
				gtk_source_view_set_show_line_numbers ((GtkSourceView*) _tmp8_, _tmp9_);
				_g_object_unref0 (view);
			}
		}
		__g_list_free__g_object_unref0_0 (view_collection);
	}
}


static void ___lambda10__g_settings_changed (GSettings* _sender, const gchar* key, gpointer self) {
	__lambda10_ (self, _sender, key);
}


static void __lambda11_ (AppSettings* self, GSettings* setting, const gchar* key) {
	GSettings* _tmp0_;
	const gchar* _tmp1_;
	gboolean _tmp2_ = FALSE;
	gboolean val;
	Latexila* _tmp3_ = NULL;
	Latexila* _tmp4_;
	GList* _tmp5_ = NULL;
	GList* _tmp6_;
	g_return_if_fail (setting != NULL);
	g_return_if_fail (key != NULL);
	_tmp0_ = setting;
	_tmp1_ = key;
	_tmp2_ = g_settings_get_boolean (_tmp0_, _tmp1_);
	val = _tmp2_;
	_tmp3_ = latexila_get_default ();
	_tmp4_ = _tmp3_;
	_tmp5_ = latexila_get_views (_tmp4_);
	_tmp6_ = _tmp5_;
	_g_object_unref0 (_tmp4_);
	{
		GList* view_collection = NULL;
		GList* view_it = NULL;
		view_collection = _tmp6_;
		for (view_it = view_collection; view_it != NULL; view_it = view_it->next) {
			DocumentView* _tmp7_;
			DocumentView* view = NULL;
			_tmp7_ = _g_object_ref0 ((DocumentView*) view_it->data);
			view = _tmp7_;
			{
				DocumentView* _tmp8_;
				gboolean _tmp9_;
				_tmp8_ = view;
				_tmp9_ = val;
				gtk_source_view_set_highlight_current_line ((GtkSourceView*) _tmp8_, _tmp9_);
				_g_object_unref0 (view);
			}
		}
		__g_list_free__g_object_unref0_0 (view_collection);
	}
}


static void ___lambda11__g_settings_changed (GSettings* _sender, const gchar* key, gpointer self) {
	__lambda11_ (self, _sender, key);
}


static void __lambda12_ (AppSettings* self, GSettings* setting, const gchar* key) {
	GSettings* _tmp0_;
	const gchar* _tmp1_;
	gboolean _tmp2_ = FALSE;
	gboolean val;
	Latexila* _tmp3_ = NULL;
	Latexila* _tmp4_;
	GList* _tmp5_ = NULL;
	GList* _tmp6_;
	g_return_if_fail (setting != NULL);
	g_return_if_fail (key != NULL);
	_tmp0_ = setting;
	_tmp1_ = key;
	_tmp2_ = g_settings_get_boolean (_tmp0_, _tmp1_);
	val = _tmp2_;
	_tmp3_ = latexila_get_default ();
	_tmp4_ = _tmp3_;
	_tmp5_ = latexila_get_documents (_tmp4_);
	_tmp6_ = _tmp5_;
	_g_object_unref0 (_tmp4_);
	{
		GList* doc_collection = NULL;
		GList* doc_it = NULL;
		doc_collection = _tmp6_;
		for (doc_it = doc_collection; doc_it != NULL; doc_it = doc_it->next) {
			Document* _tmp7_;
			Document* doc = NULL;
			_tmp7_ = _g_object_ref0 ((Document*) doc_it->data);
			doc = _tmp7_;
			{
				Document* _tmp8_;
				gboolean _tmp9_;
				_tmp8_ = doc;
				_tmp9_ = val;
				gtk_source_buffer_set_highlight_matching_brackets ((GtkSourceBuffer*) _tmp8_, _tmp9_);
				_g_object_unref0 (doc);
			}
		}
		__g_list_free__g_object_unref0_0 (doc_collection);
	}
}


static void ___lambda12__g_settings_changed (GSettings* _sender, const gchar* key, gpointer self) {
	__lambda12_ (self, _sender, key);
}


static void __lambda13_ (AppSettings* self, GSettings* setting, const gchar* key) {
	GSettings* _tmp0_;
	const gchar* _tmp1_;
	gboolean _tmp2_ = FALSE;
	gboolean val;
	Latexila* _tmp3_ = NULL;
	Latexila* _tmp4_;
	GList* _tmp5_ = NULL;
	GList* _tmp6_;
	g_return_if_fail (setting != NULL);
	g_return_if_fail (key != NULL);
	_tmp0_ = setting;
	_tmp1_ = key;
	_tmp2_ = g_settings_get_boolean (_tmp0_, _tmp1_);
	val = _tmp2_;
	_tmp3_ = latexila_get_default ();
	_tmp4_ = _tmp3_;
	_tmp5_ = latexila_get_documents (_tmp4_);
	_tmp6_ = _tmp5_;
	_g_object_unref0 (_tmp4_);
	{
		GList* doc_collection = NULL;
		GList* doc_it = NULL;
		doc_collection = _tmp6_;
		for (doc_it = doc_collection; doc_it != NULL; doc_it = doc_it->next) {
			Document* _tmp7_;
			Document* doc = NULL;
			_tmp7_ = _g_object_ref0 ((Document*) doc_it->data);
			doc = _tmp7_;
			{
				Document* _tmp8_;
				DocumentTab* _tmp9_;
				gboolean _tmp10_;
				_tmp8_ = doc;
				_tmp9_ = _tmp8_->tab;
				_tmp10_ = val;
				document_tab_set_auto_save (_tmp9_, _tmp10_);
				_g_object_unref0 (doc);
			}
		}
		__g_list_free__g_object_unref0_0 (doc_collection);
	}
}


static void ___lambda13__g_settings_changed (GSettings* _sender, const gchar* key, gpointer self) {
	__lambda13_ (self, _sender, key);
}


static void __lambda16_ (AppSettings* self, GSettings* setting, const gchar* key) {
	guint val = 0U;
	GSettings* _tmp0_;
	const gchar* _tmp1_;
	Latexila* _tmp2_ = NULL;
	Latexila* _tmp3_;
	GList* _tmp4_ = NULL;
	GList* _tmp5_;
	g_return_if_fail (setting != NULL);
	g_return_if_fail (key != NULL);
	_tmp0_ = setting;
	_tmp1_ = key;
	g_settings_get (_tmp0_, _tmp1_, "u", &val);
	_tmp2_ = latexila_get_default ();
	_tmp3_ = _tmp2_;
	_tmp4_ = latexila_get_documents (_tmp3_);
	_tmp5_ = _tmp4_;
	_g_object_unref0 (_tmp3_);
	{
		GList* doc_collection = NULL;
		GList* doc_it = NULL;
		doc_collection = _tmp5_;
		for (doc_it = doc_collection; doc_it != NULL; doc_it = doc_it->next) {
			Document* _tmp6_;
			Document* doc = NULL;
			_tmp6_ = _g_object_ref0 ((Document*) doc_it->data);
			doc = _tmp6_;
			{
				Document* _tmp7_;
				DocumentTab* _tmp8_;
				guint _tmp9_;
				_tmp7_ = doc;
				_tmp8_ = _tmp7_->tab;
				_tmp9_ = val;
				document_tab_set_auto_save_interval (_tmp8_, _tmp9_);
				_g_object_unref0 (doc);
			}
		}
		__g_list_free__g_object_unref0_0 (doc_collection);
	}
}


static void ___lambda16__g_settings_changed (GSettings* _sender, const gchar* key, gpointer self) {
	__lambda16_ (self, _sender, key);
}


static gboolean __lambda18_ (AppSettings* self) {
	gboolean result = FALSE;
	self->priv->timeout_id = (guint) 0;
	symbols_reload_most_used_symbols ();
	result = FALSE;
	return result;
}


static gboolean ___lambda18__gsource_func (gpointer self) {
	gboolean result;
	result = __lambda18_ (self);
	return result;
}


static void __lambda17_ (AppSettings* self, GSettings* setting, const gchar* key) {
	guint _tmp0_;
	guint _tmp2_ = 0U;
	g_return_if_fail (setting != NULL);
	g_return_if_fail (key != NULL);
	_tmp0_ = self->priv->timeout_id;
	if (_tmp0_ != ((guint) 0)) {
		guint _tmp1_;
		_tmp1_ = self->priv->timeout_id;
		g_source_remove (_tmp1_);
	}
	_tmp2_ = g_timeout_add_seconds_full (G_PRIORITY_DEFAULT, (guint) 1, ___lambda18__gsource_func, g_object_ref (self), g_object_unref);
	self->priv->timeout_id = _tmp2_;
}


static void ___lambda17__g_settings_changed (GSettings* _sender, const gchar* key, gpointer self) {
	__lambda17_ (self, _sender, key);
}


static void app_settings_initialize (AppSettings* self) {
	GSettings* _tmp0_ = NULL;
	GSettings* prefs;
	GSettings* _tmp1_;
	GSettings* _tmp2_ = NULL;
	GSettings* _tmp8_;
	GSettings* _tmp9_;
	GSettings* _tmp10_;
	GSettings* _tmp11_;
	GSettings* _tmp12_;
	GSettings* _tmp13_;
	GSettings* _tmp14_;
	GSettings* _tmp15_;
	GSettings* _tmp16_;
	GSettings* _tmp17_;
	GSettings* _tmp18_;
	g_return_if_fail (self != NULL);
	_tmp0_ = g_settings_get_child ((GSettings*) self, "preferences");
	prefs = _tmp0_;
	_tmp1_ = prefs;
	_tmp2_ = g_settings_get_child (_tmp1_, "editor");
	_g_object_unref0 (self->priv->editor);
	self->priv->editor = _tmp2_;
	if (!DESKTOP_SCHEMAS) {
		app_settings_set_system_font (self, "Monospace 10");
	} else {
		GSettings* _tmp3_;
		GSettings* _tmp4_;
		gchar* _tmp5_ = NULL;
		gchar* _tmp6_;
		GSettings* _tmp7_;
		_tmp3_ = g_settings_new ("org.gnome.desktop.interface");
		_g_object_unref0 (self->priv->desktop_interface);
		self->priv->desktop_interface = _tmp3_;
		_tmp4_ = self->priv->desktop_interface;
		_tmp5_ = g_settings_get_string (_tmp4_, "monospace-font-name");
		_tmp6_ = _tmp5_;
		app_settings_set_system_font (self, _tmp6_);
		_g_free0 (_tmp6_);
		_tmp7_ = self->priv->desktop_interface;
		g_signal_connect_object (_tmp7_, "changed::monospace-font-name", (GCallback) ____lambda4__g_settings_changed, self, 0);
	}
	_tmp8_ = self->priv->editor;
	g_signal_connect_object (_tmp8_, "changed::use-default-font", (GCallback) ___lambda5__g_settings_changed, self, 0);
	_tmp9_ = self->priv->editor;
	g_signal_connect_object (_tmp9_, "changed::editor-font", (GCallback) ___lambda6__g_settings_changed, self, 0);
	_tmp10_ = self->priv->editor;
	g_signal_connect_object (_tmp10_, "changed::scheme", (GCallback) ___lambda7__g_settings_changed, self, 0);
	_tmp11_ = self->priv->editor;
	g_signal_connect_object (_tmp11_, "changed::tabs-size", (GCallback) ___lambda8__g_settings_changed, self, 0);
	_tmp12_ = self->priv->editor;
	g_signal_connect_object (_tmp12_, "changed::insert-spaces", (GCallback) ___lambda9__g_settings_changed, self, 0);
	_tmp13_ = self->priv->editor;
	g_signal_connect_object (_tmp13_, "changed::display-line-numbers", (GCallback) ___lambda10__g_settings_changed, self, 0);
	_tmp14_ = self->priv->editor;
	g_signal_connect_object (_tmp14_, "changed::highlight-current-line", (GCallback) ___lambda11__g_settings_changed, self, 0);
	_tmp15_ = self->priv->editor;
	g_signal_connect_object (_tmp15_, "changed::bracket-matching", (GCallback) ___lambda12__g_settings_changed, self, 0);
	_tmp16_ = self->priv->editor;
	g_signal_connect_object (_tmp16_, "changed::auto-save", (GCallback) ___lambda13__g_settings_changed, self, 0);
	_tmp17_ = self->priv->editor;
	g_signal_connect_object (_tmp17_, "changed::auto-save-interval", (GCallback) ___lambda16__g_settings_changed, self, 0);
	_tmp18_ = self->priv->editor;
	g_signal_connect_object (_tmp18_, "changed::nb-most-used-symbols", (GCallback) ___lambda17__g_settings_changed, self, 0);
	_g_object_unref0 (prefs);
}


static void app_settings_set_font (AppSettings* self, const gchar* font) {
	Latexila* _tmp0_ = NULL;
	Latexila* _tmp1_;
	GList* _tmp2_ = NULL;
	GList* _tmp3_;
	g_return_if_fail (self != NULL);
	g_return_if_fail (font != NULL);
	_tmp0_ = latexila_get_default ();
	_tmp1_ = _tmp0_;
	_tmp2_ = latexila_get_views (_tmp1_);
	_tmp3_ = _tmp2_;
	_g_object_unref0 (_tmp1_);
	{
		GList* view_collection = NULL;
		GList* view_it = NULL;
		view_collection = _tmp3_;
		for (view_it = view_collection; view_it != NULL; view_it = view_it->next) {
			DocumentView* _tmp4_;
			DocumentView* view = NULL;
			_tmp4_ = _g_object_ref0 ((DocumentView*) view_it->data);
			view = _tmp4_;
			{
				DocumentView* _tmp5_;
				const gchar* _tmp6_;
				_tmp5_ = view;
				_tmp6_ = font;
				document_view_set_font_from_string (_tmp5_, _tmp6_);
				_g_object_unref0 (view);
			}
		}
		__g_list_free__g_object_unref0_0 (view_collection);
	}
}


const gchar* app_settings_get_system_font (AppSettings* self) {
	const gchar* result;
	const gchar* _tmp0_;
	g_return_val_if_fail (self != NULL, NULL);
	_tmp0_ = self->priv->_system_font;
	result = _tmp0_;
	return result;
}


static void app_settings_set_system_font (AppSettings* self, const gchar* value) {
	const gchar* _tmp0_;
	gchar* _tmp1_;
	g_return_if_fail (self != NULL);
	_tmp0_ = value;
	_tmp1_ = g_strdup (_tmp0_);
	_g_free0 (self->priv->_system_font);
	self->priv->_system_font = _tmp1_;
	g_object_notify ((GObject *) self, "system-font");
}


static void app_settings_class_init (AppSettingsClass * klass) {
	app_settings_parent_class = g_type_class_peek_parent (klass);
	g_type_class_add_private (klass, sizeof (AppSettingsPrivate));
	G_OBJECT_CLASS (klass)->get_property = _vala_app_settings_get_property;
	G_OBJECT_CLASS (klass)->set_property = _vala_app_settings_set_property;
	G_OBJECT_CLASS (klass)->finalize = app_settings_finalize;
	g_object_class_install_property (G_OBJECT_CLASS (klass), APP_SETTINGS_SYSTEM_FONT, g_param_spec_string ("system-font", "system-font", "system-font", NULL, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE));
}


static void app_settings_instance_init (AppSettings * self) {
	self->priv = APP_SETTINGS_GET_PRIVATE (self);
	self->priv->timeout_id = (guint) 0;
}


static void app_settings_finalize (GObject* obj) {
	AppSettings * self;
	self = APP_SETTINGS (obj);
	_g_object_unref0 (self->priv->editor);
	_g_object_unref0 (self->priv->desktop_interface);
	_g_free0 (self->priv->_system_font);
	G_OBJECT_CLASS (app_settings_parent_class)->finalize (obj);
}


GType app_settings_get_type (void) {
	static volatile gsize app_settings_type_id__volatile = 0;
	if (g_once_init_enter (&app_settings_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (AppSettingsClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) app_settings_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (AppSettings), 0, (GInstanceInitFunc) app_settings_instance_init, NULL };
		GType app_settings_type_id;
		app_settings_type_id = g_type_register_static (G_TYPE_SETTINGS, "AppSettings", &g_define_type_info, 0);
		g_once_init_leave (&app_settings_type_id__volatile, app_settings_type_id);
	}
	return app_settings_type_id__volatile;
}


static void _vala_app_settings_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec) {
	AppSettings * self;
	self = APP_SETTINGS (object);
	switch (property_id) {
		case APP_SETTINGS_SYSTEM_FONT:
		g_value_set_string (value, app_settings_get_system_font (self));
		break;
		default:
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
		break;
	}
}


static void _vala_app_settings_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec) {
	AppSettings * self;
	self = APP_SETTINGS (object);
	switch (property_id) {
		case APP_SETTINGS_SYSTEM_FONT:
		app_settings_set_system_font (self, g_value_get_string (value));
		break;
		default:
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
		break;
	}
}



